@@ -2,8 +2,9 @@
 #' SPC_AAM
 #' @description A single linear model with minimization on absolute area.
 #' @details  This function is to process phase error correction through a single linear model with minimization on absolute area, followed by
-#'    Polynomial baseline correction.
+#'    polynomial baseline correction if necessary
 #' @param specdat A complex number vector of observed frequency domain data
+#' @param withBC A logical parameter that enables/disables baseline correction after baseline correction
 #' @return A numeric vector of phase corrected absorption spectrum
 #' @concept phase correction
 #' @author Aixiang Jiang
@@ -24,7 +25,7 @@
 #' @export
 
 
-SPC_AAM = function (specdat){
+SPC_AAM = function (specdat, withBC = TRUE){
 
   hdat=cbind(Re(specdat), Im(specdat))
 
@@ -44,9 +45,14 @@ SPC_AAM = function (specdat){
   dat3col=cbind(hdat, angles)
   phasedDat=t(apply(dat3col, 1, phaseCorr2))
 
-  ##### return phased plus baseline corrected spectrum
-  tryBL=baseline::baseline(t(phasedDat[,1]),method="modpolyfit")
-  return(baseline::getCorrected(tryBL)[1,])
+  phasedAll = phasedDat[,1]
+
+  if(withBC == TRUE){
+    tryBL=myBaseline(phasedAll,bsDf=5, BL_method="modpolyfit")
+    phasedAll = as.numeric(tryBL)
+  }
+
+  return(phasedAll)
 
 }
 
