@@ -6,6 +6,6 @@ areaDiff = function(phasePara, specDat) {
   phases=phasePara[1]+phasePara[2]*c(1:n)/n
 
   dat3col=cbind(specDat, phases)
-  phasedDat=t(apply(dat3col, 1, phaseCorr2)) ### output is a two column matrix: the phased real and the phased imaginary of freq data
+  phasedDat=t(apply(dat3col, 1, phaseCorr2))
   sum(abs(phasedDat[,1]))-sum(phasedDat[,1])
 }
